@@ -1,6 +1,6 @@
 # sumFREGAT (2017-2018) Gulnara R. Svishcheva & Nadezhda M. Belonogova, ICG SB RAS
 
-'sumchi' <- function (score.file, gene.file, genes = 'all', cor.path = 'cor/',
+'sumchi' <- function (score.file, gene.file, genes = 'all', cor.path = 'cor/', approximation = TRUE,
 anno.type = '', method = 'kuonen', acc = 1e-8, lim = 1e+6, write.file = FALSE, quiet = FALSE) {
 
 	my.args <- c(as.list(environment()), weights.function = NULL,
